<?php
/**
 * @package		Portal
 * @author		<a href='https://www.devfuse.com'>DevFuse</a>
 * @copyright	(c) 2015-2017 DevFuse
 */

namespace IPS\portal\modules\admin\portal;

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * blocks
 */
class _blocks extends \IPS\Node\Controller
{
	/**
	 * Node Class
	 */
	protected $nodeClass = 'IPS\portal\Blocks';
	
	/**
	 * Execute
	 *
	 * @return	void
	 */
	public function execute()
	{
		\IPS\Dispatcher::i()->checkAcpPermission( 'blocks_manage' );
		parent::execute();
	}
    
	public function _getRootButtons()
	{
		$buttons = parent::_getRootButtons();
		
		$buttons['import']  = array(
			'icon'	=> 'upload',
			'title'	=> 'portal_block_import',
			'link'	=> \IPS\Http\Url::internal( $this->url->setQueryString( array( 'do' => 'import' ) ) ),
			'data'	=> array( 'ipsDialog' => '', 'ipsDialog-title' => \IPS\Member::loggedIn()->language()->addToStack('portal_block_import') )
			);

		return $buttons;
	}   
    
	/**
	 * Install Form
	 *
	 * @return	void
	 */
	public function import()
	{
		/* Build form */
		$form = new \IPS\Helpers\Form( NULL, 'import' );
		if ( isset( \IPS\Request::i()->id ) )
		{
			$form->hiddenValues['id'] = \IPS\Request::i()->id;
		}
		$form->add( new \IPS\Helpers\Form\Upload( 'portal_block_upload', NULL, TRUE, array( 'allowedFileTypes' => array( 'xml' ), 'temporary' => TRUE ) ) );
		$activeTabContents = $form;
		
		/* Handle submissions */
		if ( $values = $form->values() )
		{
			/* Move it to a temporary location */
			$tempFile = tempnam( \IPS\TEMP_DIRECTORY, 'IPS' );
			move_uploaded_file( $values['block_upload'], $tempFile );
								
			/* Initate a redirector */
			\IPS\Output::i()->redirect( \IPS\Http\Url::internal( 'app=portal&module=portal&controller=blocks&do=doImport&file=' . urlencode( $tempFile ) . '&key=' . md5_file( $tempFile ) . ( isset( \IPS\Request::i()->id ) ? '&id=' . \IPS\Request::i()->id : '' ) ) );
		}
		
		/* Display */
		\IPS\Output::i()->output = $form;
	}       
    
	/**
	 * Install
	 *
	 * @return	void
	 */
	public function doImport()
	{
		if ( !file_exists( \IPS\Request::i()->file ) or md5_file( \IPS\Request::i()->file ) !== \IPS\Request::i()->key )
		{
			\IPS\Output::i()->error( 'generic_error', '3C145/3', 500, '' );
		}
		
		\IPS\Output::i()->output = new \IPS\Helpers\MultipleRedirect(
			\IPS\Http\Url::internal( 'app=portal&module=portal&controller=blocks&do=doImport&file=' . urlencode( \IPS\Request::i()->file ) . '&key=' .  \IPS\Request::i()->key . '&id=' . \IPS\Request::i()->id ),
			function( $data )
			{
				/* Open XML file */
				$xml = new \XMLReader;
				$xml->open( \IPS\Request::i()->file );

				if ( ! @$xml->read() )
				{
					\IPS\Output::i()->error( 'xml_upload_invalid', '2C145/D', 403, '' );
				}
                
                while ($xml->read()) 
                { 
                    if( $xml->name=='block' && $xml->nodeType == \XMLReader::ELEMENT ) 
                    {
                        /* Get block data */
                        $blockData = new \SimpleXMLElement( $xml->readOuterXml() );
                
                        /* Add/update block */
    				  	try
    				  	{
    					  	$block = \IPS\portal\Blocks::load( $blockData->name, 'name' );
    				  	}
    				  	catch ( \OutOfRangeException $e )
    				  	{
    					  	$block = new \IPS\portal\Blocks;
    					}                   
    
    					$block->title      = $blockData->title;
                        $block->template   = intval( $blockData->template );
                        $block->block_code = $blockData->block_code;  
                        $block->show_block = intval( $blockData->show_block );                                                           
    					$block->save();        
                    }
                }

				return NULL;
			},
			function()
			{
				\IPS\Output::i()->redirect( \IPS\Http\Url::internal( 'app=portal&module=portal&controller=blocks' ), 'saved' );
			}
		);
	}    
    
	/**
	 * Export
	 *
	 * @return	void
	 */
	protected function export()
	{
		/* Load block */
		try
		{
			$block = \IPS\portal\Blocks::load( \IPS\Request::i()->id );
		}
		catch ( \OutOfRangeException $e )
		{
			\IPS\Output::i()->error( 'node_error', '2C126/5', 404, '' );
		}
			
		/* Init */
		$xml = new \XMLWriter;
		$xml->openMemory();
		$xml->setIndent( TRUE );
		$xml->startDocument( '1.0', 'UTF-8' );
				
		/* Root tag */
		$xml->startElement('blockexport');
        $xml->startElement('portalblock');
        $xml->startElement('block');
        
        /* Loop through our block fields */
		foreach( array( 'title', 'name', 'template', 'block_code', 'show_block' ) as $field )
		{
			$xml->startElement( $field );
            
            /* Block code? */
            if( $field == 'block_code' )
            {
                $xml->writeCData( $block->$field );
            }
            else
            {
                $xml->text( $block->$field );    
            }          
			
			$xml->endElement();
		}        
            
        /* End and download */    
        $xml->endElement();        
        $xml->endDocument();

		\IPS\Output::i()->sendOutput( $xml->outputMemory(), 200, 'application/xml', array( 'Content-Disposition' => \IPS\Output::getContentDisposition( 'attachment', 'portal_block.xml' ) ) );
	}    
    
	/**
	 * Add/Edit Form
	 *
	 * @return void
	 */
	protected function form()
	{
		parent::form();

		if ( \IPS\Request::i()->id )
		{
			\IPS\Output::i()->title = \IPS\Member::loggedIn()->language()->addToStack('portal_block_edit') . ': ' . \IPS\Output::i()->title;
		}
		else
		{
			\IPS\Output::i()->title = \IPS\Member::loggedIn()->language()->addToStack('portal_block_add');
		}
	}
}