<?php
/**
 * @package		Portal
 * @author		<a href='https://www.devfuse.com'>DevFuse</a>
 * @copyright	(c) 2015-2017 DevFuse
 */
 
namespace IPS\portal;

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * Blocks Node
 */
class _Blocks extends \IPS\Node\Model
{
	protected static $multitons;
    public static $databaseColumnId = 'block_id';
    public static $databaseIdFields = array('name');
	public static $databaseTable = 'portal_blocks';
	public static $databasePrefix = '';
	public static $nodeTitle = 'portal_block_node';
	public static $databaseColumnMap = array(
		'title'					=> 'title',  
	);

	/**
	 * Set the title
	 *
	 * @param	string	$title	Title
	 * @return	void
	 */
	public function set_title( $title )
	{
		$this->_data['title'] = $title;
		$this->_data['name'] = \IPS\Http\Url::seoTitle( $title );
	}


	public function get__title()
	{
		if ( !$this->block_id )
		{
			return '';
		}	   
       
        return $this->title;
	}
    

	/**
	 * Get SEO name
	 *
	 * @return	string
	 */
	public function get_title_seo()
	{
		if( !$this->_data['name'] )
		{
			$this->title_seo	= \IPS\Http\Url::seoTitle( $this->title );
			$this->save();
		}

		return $this->_data['name'] ?: \IPS\Http\Url::seoTitle( $this->title );
	}
    
	/**
	 * [Node] Get whether or not this node is enabled
	 *
	 * @note	Return value NULL indicates the node cannot be enabled/disabled
	 * @return	bool|null
	 */
	protected function get__enabled()
	{
		return $this->show_block;
	}

	/**
	 * [Node] Set whether or not this node is enabled
	 *
	 * @param	bool|int	$enabled	Whether to set it enabled or disabled
	 * @return	void
	 */
	protected function set__enabled( $enabled )
	{
		$this->show_block	= $enabled;
	}  
    
	/**
	 * [Node] Get buttons to display in tree
	 * Example code explains return value
	 * @encode
	 * @param	string	$url		Base URL
	 * @param	bool	$subnode	Is this a subnode?
	 * @return	array
	 */
	public function getButtons( $url, $subnode=FALSE )
	{
		$buttons = array();
        
		$buttons = array_merge( $buttons, parent::getButtons( $url, $subnode ) );        
        
		if ( $this->canEdit() )
		{
			$buttons['download'] = array(
				'icon'	=> 'download',
				'title'	=> 'portal_block_export',
				'link'	=> \IPS\Http\Url::internal( "app=portal&module=portal&controller=blocks&do=export&id={$this->_id}" ),
			);
		}        
		
		return $buttons;
	}    
      
	/**
	 * [Node] Add/Edit Form
	 *
	 * @param	\IPS\Helpers\Form	$form	The form
	 * @return	void
	 */
	public function form( &$form )
	{        
        /* Block form */
		$form->add( new \IPS\Helpers\Form\Text( 'portal_block_title', $this->block_id ? $this->title : '', TRUE ) );
		$form->add( new \IPS\Helpers\Form\YesNo( 'portal_block_show_block', $this->block_id ? $this->show_block : TRUE, FALSE ) );
		$form->add( new \IPS\Helpers\Form\YesNo( 'portal_block_template', $this->block_id ? $this->template : FALSE, FALSE ) );
        $form->add( new \IPS\Helpers\Form\Codemirror( 'portal_block_block_code', $this->block_id ? $this->block_code : '', TRUE, array( 'rows' => 15 ) ) );
	}
	
	/**
	 * [Node] Format form values from add/edit form for save
	 *
	 * @param	array	$values	Values from the form
	 * @return	array
	 */
	public function formatFormValues( $values )
	{  
	    /* Remove prefix */
 		foreach( $values as $k => $v )
		{
			if( mb_substr( $k, 0, 13 ) === 'portal_block_' )
			{
				unset( $values[ $k ] );
				$values[ mb_substr( $k, 13 ) ] = $v;
			}
		}	   
       
		if ( !$this->block_id )
		{
			//$this->save();
		}

		return $values;
	}

	/**
	 * @brief	Cached URL
	 */
	protected $_url	= NULL;

	/**
	 * Get URL
	 *
	 * @return	\IPS\Http\Url
	 */
	public function url()
	{
		if( $this->_url === NULL )
		{
			$this->_url = \IPS\Http\Url::internal( "app=portal&module=portal&controller=view&id={$this->_id}", 'front', '', $this->title_seo );
		}

		return $this->_url;
	}
 

	/**
	 * [ActiveRecord] Delete Record
	 *
	 * @return	void
	 */
	public function delete()
	{
		return parent::delete();
	}

	/**
	 * Search
	 *
	 * @param	string		$column	Column to search
	 * @param	string		$query	Search query
	 * @param	string|null	$order	Column to order by
	 * @param	mixed		$where	Where clause
	 * @return	array
	 */
	public static function search( $column, $query, $order=NULL, $where=array() )
	{
		if ( $column === '_title' )
		{
			$column	= 'title';
		}

		if( $order == '_title' )
		{
			$order	= 'title';
		}

		return parent::search( $column, $query, $order, $where );
	}
    
	/**
	 * Parse post images
	 *
	 * @return	string
	 */
	public static function parseImages( $topic=NULL )
	{
	    /* Ok then */
	    if( !$topic )
        {
            return NULL;
        }	
        
        $postContents = '';   
       
        /* Loop through posts and get post contents */
        $postSearch = \IPS\Settings::i()->portal_thumbnails_posts ? \IPS\Settings::i()->portal_thumbnails_posts : 25;
        foreach( $topic->comments( $postSearch, 0 ) as $post )
        {
            $postContents .= $post->post;   
        }

	    /* Really? */
	    if( !$postContents )
        {
            return NULL;
        }
       
	    /* Parse post now */
        \IPS\Output::i()->parseFileObjectUrls( $postContents );
        
		/* Start domdocument, force it to UTF-8 */
		libxml_use_internal_errors(TRUE);
		$doc = new \DOMDocument( '1.0', 'UTF-8' );
		@$doc->loadHTML( "<head><meta http-equiv='Content-Type' content='text/html; charset=utf-8'/></head>" . $postContents );	   

        /* Get all post images */
        $_images = $doc->getElementsByTagName('img');
        $images  = array();  
        
        foreach( $_images as $img ) 
        {      
            /* Skip emoticons */
			if( $img->hasAttribute("data-emoticon") )
			{
				continue;
			}            
            
            /* Get image url */
            $imageURL = $img->getAttribute('src');
            $images[] = $imageURL;         
        }

        /* No images to show for this topic */
        if( !count( $images ) )
        {
            return NULL;
        }
        
        /* Return first image */
        return current( $images );
	}         
}