<?php
/**
 * @package		Portal
 * @author		<a href='https://www.devfuse.com'>DevFuse</a>
 * @copyright	(c) 2015-2017 DevFuse
 */

namespace IPS\portal\widgets;

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * portalBlock Widget
 */
class _portalBlock extends \IPS\Widget
{
	/**
	 * @brief	Widget Key
	 */
	public $key = 'portalBlock';
	
	/**
	 * @brief	App
	 */
	public $app = 'portal';
		
	/**
	 * @brief	Plugin
	 */
	public $plugin = '';
    
	/**
	 * Initialise this widget
	 *
	 * @return void
	 */ 
	public function init()
	{
        $this->template( array( \IPS\Theme::i()->getTemplate( 'widgets', $this->app, 'front' ), $this->key ) );
	}    
	
	/**
	 * Specify widget configuration
	 *
	 * @param	null|\IPS\Helpers\Form	$form	Form object
	 * @return	null|\IPS\Helpers\Form
	 */
	public function configuration( &$form=null )
	{
	    if ( $form === null )
	    {
		    $form = new \IPS\Helpers\Form;
	    }

	    $form->add( new \IPS\Helpers\Form\Node( 'portal_widget_portal_block', ( isset( $this->configuration['portal_widget_portal_block'] ) ? $this->configuration['portal_widget_portal_block'] : NULL ), FALSE, array(
            'class' => '\IPS\portal\Blocks',
            'permissionCheck' => function( $node )
                {
	                if ( in_array( 'IPS\portal\Blocks', array_keys( class_parents( $node ) ) ) )
	                {
		                return FALSE;
	                }

	                return TRUE;
                }
        ) ) );

	    return $form;
 	} 
 	
 	 /**
 	 * Ran before saving widget configuration
 	 *
 	 * @param	array	$values	Values from form
 	 * @return	array
 	 */
 	public function preConfig( $values )
 	{
		$newValues = array();

		if ( isset( $values['portal_widget_portal_block'] ) )
		{
			$newValues['portal_widget_portal_block'] = $values['portal_widget_portal_block']->block_id;
		}

		return $newValues;
 	}

	/**
	 * Render a widget
	 *
	 * @return	string
	 */
	public function render()
	{
	    /* Stop it */
		if( !isset( $this->configuration['portal_widget_portal_block'] ) )
		{
            return '';
        }
        
        /* Get out block */
		try
		{
			$block = \IPS\portal\Blocks::load( $this->configuration['portal_widget_portal_block'] );

			if ( !$block->show_block )
			{
				return '';
			}
		}
		catch( \OutOfRangeException $ex )
		{
			return '';
		}        
        
        /* Wrap block contents */
        ob_start();
        eval("?>".$block->block_code."<?php\n");
        $content = ob_get_contents();
        ob_end_clean();	
        
        /* Wrap block code with template? */
        if( $block->template )
        {
            $content = \IPS\Theme::i()->getTemplate( 'widgets', 'portal', 'front' )->templateWrap( $block, $content );            
        }

        return $content;
	}
}